@@ -1,5 +1,3 @@
-import re
-import time
 import logging
 import traceback
 from django.core.exceptions import ImproperlyConfigured
@@ -17,7 +15,7 @@ class HeaderToLabelMiddleware(object):
     """
     Provides full logging of requests and responses
     """
-    _initial_http_body = None
+    _initial_http_body = b""
     _request_start_time = None
     _TRUNCATE_INDICATOR = "---[TRUNCATED]---"
     _OBFUSCATE_INDICATOR = "---[HIDDEN]---"
@@ -38,9 +36,6 @@ class HeaderToLabelMiddleware(object):
         if not hasattr(settings, NIM_DJANGO_REQUEST_LOG_LEVEL_NAME):
             raise ImproperlyConfigured(f"Please set {NIM_DJANGO_REQUEST_LOG_LEVEL_NAME}, it is the value of the header name containing the correlation id")
 
-        if not hasattr(settings, LOGGING):
-            raise ImproperlyConfigured(f"Please set {LOGGING}, it is the list of log name whose log level will be updated")
-
         self.get_response = get_response
 
     def process_request(self, request):
@@ -86,10 +81,10 @@ class HeaderToLabelMiddleware(object):
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
             body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body,
-                                            getattr(settings, MAX_REQUEST_RESPONSE_SIZE)) if response.status_code < 400 else self._initial_http_body),
+                                            getattr(settings, MAX_REQUEST_RESPONSE_SIZE)) if response.status_code < 400 else Utils.obfuscate_body(self._initial_http_body.decode("UTF-8"))),
             status_code=response.status_code,
             response=Utils.obfuscate_response(Utils.adjust_string_length(response.content,
-                                                settings.MAX_REQUEST_RESPONSE_SIZE) if response.status_code < 400 else response.content),
+                                                settings.MAX_REQUEST_RESPONSE_SIZE) if response.status_code < 400 else Utils.obfuscate_body(response.content.decode("UTF-8"))),
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry.update(headers)
@@ -103,6 +98,7 @@ class HeaderToLabelMiddleware(object):
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry_info.update(log_entry_info)
+        log_entry_info.update(headers)
 
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
         for label in log_label_request_settings:
@@ -131,7 +127,7 @@ class HeaderToLabelMiddleware(object):
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
             body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
-            status_code="500",
+            status_code=500,
             exception=str(exception),
             url=Utils.obfuscate_url(request.build_absolute_uri()),
             stack_trace=traceback.format_exc()
@@ -142,7 +138,7 @@ class HeaderToLabelMiddleware(object):
             type=self._ERROR,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=Utils.get_time_in_milliseconds(),
-            status_code="500",
+            status_code=500,
             method=request.method,
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
